import contextlib
import matplotlib.pyplot as plt


@contextlib.contextmanager
def pltsave(filename, *, title=None, xlabel=None, ylabel=None, shape=(1, 1), size=None, dpi=None):
    """Context manager for quickly making and saving a plot.
        Takes title, xlable, ylabel, shape, and size arguments.
        Yields the figure object and the first ax object.
        Savesthe plot after the yield.
    """
    fig = plt.figure(figsize=size)
    ax = fig.add_subplot(*(shape + (1,)))
    if not title is None:
        ax.set_title(title)
    if not xlabel is None:
        ax.set_xlabel(xlabel)
    if not ylabel is None:
        ax.set_ylabel(ylabel)
    yield (fig, ax)
    fig.savefig(filename, dpi=dpi)
    fig.clear()



from setuptools import setup

import os
long_description = 'Shortcuts for saving and exporting matplotlib plots.'
if os.path.exists('README.txt'):
    long_description = open('README.txt').read()

setup(
    name='matplotsave',
    author='Christopher Chen',
    author_email='christopher.chen1995@gmail.com',
    version='0.1.3',
    description="""Helper functions and context manager to make it easier to save matplotlib plots as images.""",
    long_description=long_description,
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Operating System :: OS Independent",
    ],
    keywords="matplotlib save export images context managers functions",
    url='https://bitbucket.org/TheCDC/matplotsave',
    license='Public Domain',
    packages=['matplotsave'],
    download_url="https://bitbucket.org/TheCDC/matplotsave/get/HEAD.zip",
    install_requires=[],
    zip_safe=True
)
